﻿//-----------------------------------------------------------------------
// <copyright file="ServerExtensionReadWrite.cs" company="Beckhoff Automation GmbH & Co. KG">
//     Copyright (c) Beckhoff Automation GmbH & Co. KG. All Rights Reserved.
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Threading;
using TcHmiSrv.Core;
using TcHmiSrv.Core.General;
using TcHmiSrv.Core.Listeners;
using TcHmiSrv.Core.Tools.Management;

namespace ServerExtensionReadWrite
{
    // Represents the default type of the TwinCAT HMI server extension.
    public class ServerExtensionReadWrite : IServerExtension
    {
        private readonly RequestListener requestListener = new RequestListener();

        private Timer iTimer = new Timer(timerMethod, null, 200, 500);
        private static long aString = 0;

        private static object myLock = new object();

        private static void timerMethod(object state)
        {
            
            lock (myLock)
            {
                aString = DateTime.Now.Second;
            }
        }

        /*
GETTING STARTED

The recommended way to get started is to look at a few of the sample extensions that are available on GitHub:
https://github.com/Beckhoff/TF2000_Server_Samples

The full documentation for the extension API can be found in the Beckhoff Information System:
https://infosys.beckhoff.com/english.php?content=../content/1033/te2000_tc3_hmi_engineering/10591698827.html

An offline version of this documentation is available at this path:
%TWINCAT3DIR%..\Functions\TE2000-HMI-Engineering\Infrastructure\TcHmiServer\docs\TcHmiSrvExtNet.Core.Documentation.chm
*/

        // Called after the TwinCAT HMI server loaded the server extension.
        public ErrorValue Init()
        {
            this.requestListener.OnRequest += this.OnRequest;
            return ErrorValue.HMI_SUCCESS;
        }

        // Called when a client requests a symbol from the domain of the TwinCAT HMI server extension.
        private void OnRequest(object sender, TcHmiSrv.Core.Listeners.RequestListenerEventArgs.OnRequestEventArgs e)
        {
            try
            {
                e.Commands.Result = ServerExtensionReadWriteErrorValue.ServerExtensionReadWriteSuccess;

                foreach (Command command in e.Commands)
                {
                    try
                    {
                        // Use the mapping to check which command is requested
                        switch (command.Mapping)
                        {
                            case "ReadValueString":
                                //command.IsSet is not set from HMI so IsSet is false
                                if (command.IsSet == true)
                                {

                                    command.ReadValue = 7777;
                                    //command.IsSet is true as the ReadValue has been updated
                                }
                                command.ReadValue = "dfs"; //Just a crap
                                command.ReadValue = aString.ToString(); //Set the seconds to string for HMI
                                if (command.IsSet == true)
                                {
                                    command.ReadValue = 7777;
                                }
                                command.ExtensionResult = ServerExtensionReadWriteErrorValue.ServerExtensionReadWriteSuccess;
                                command.ResultString = "ReadValue1 '" + command.Mapping + "' not handled.";
                                break;

                            case "WriteValueInt":
                                command.ReadValue = aString;
                                if (command.IsSet == true && command.WriteValue != null)
                                {
                                    command.ReadValue = 7777;
                                }
                                else
                                {

                                }
                                command.ExtensionResult = ServerExtensionReadWriteErrorValue.ServerExtensionReadWriteSuccess;
                                command.ResultString = "WriteValue1 '" + command.Mapping + "' not handled.";
                                break;

                            default:
                                command.ExtensionResult = ServerExtensionReadWriteErrorValue.ServerExtensionReadWriteFail;
                                command.ResultString = "Unknown command '" + command.Mapping + "' not handled.";
                                break;
                        }
                    }
                    catch (Exception ex)
                    {
                        command.ExtensionResult = ServerExtensionReadWriteErrorValue.ServerExtensionReadWriteFail;
                        command.ResultString = "Calling command '" + command.Mapping + "' failed! Additional information: " + ex.ToString();
                    }
                }
            }
            catch (Exception ex)
            {
                throw new TcHmiException(ex.ToString(), ErrorValue.HMI_E_EXTENSION);
            }
        }
    }
}
